pub enum WgpuSetup {
CreateNew(WgpuSetupCreateNew),
Existing(WgpuSetupExisting),
}Variants
CreateNew(WgpuSetupCreateNew)
Construct a wgpu setup using some predefined settings & heuristics. This is the default option. You can customize most behaviours overriding the supported backends, power preferences, and device description.
By default can also be configured with various environment variables:
WGPU_BACKEND:vulkan,dx12,metal,opengl,webgpuWGPU_POWER_PREF:low,highornoneWGPU_TRACE: Path to a file to output a wgpu trace file.
Each instance flag also comes with an environment variable (for details see wgpu::InstanceFlags):
WGPU_VALIDATION: Enables validation (enabled by default in debug builds).WGPU_DEBUG: Generate debug information in shaders and objects (enabled by default in debug builds).WGPU_ALLOW_UNDERLYING_NONCOMPLIANT_ADAPTER: Whether wgpu should expose adapters that run on top of non-compliant adapters.WGPU_GPU_BASED_VALIDATION: Enable GPU-based validation.
Existing(WgpuSetupExisting)
Run on an existing wgpu setup.
Implementations
Sourceimpl WgpuSetup
impl WgpuSetup
Sourcepub fn from_display_handle(display_handle: impl EguiDisplayHandle) -> Self
pub fn from_display_handle(display_handle: impl EguiDisplayHandle) -> Self
Creates a new WgpuSetup::CreateNew with the given display handle.
See WgpuSetupCreateNew::from_display_handle for details.
Sourcepub fn without_display_handle() -> Self
pub fn without_display_handle() -> Self
Creates a new WgpuSetup::CreateNew without a display handle.
See WgpuSetupCreateNew::without_display_handle for details.
Sourceimpl WgpuSetup
impl WgpuSetup
Sourcepub async fn new_instance(&self) -> Instance
pub async fn new_instance(&self) -> Instance
Creates a new wgpu::Instance or clones the existing one.
Does not store the wgpu instance, so calling this repeatedly may create a new instance every time!