pub struct SurfaceConfig {
pub present_mode: PresentMode,
pub desired_maximum_frame_latency: Option<u32>,
}Expand description
Runtime-mutable subset of WgpuConfiguration.
Edit any field to have the surface reconfigured on the next paint.
Fields
present_mode: PresentModePresent mode used for the primary surface.
desired_maximum_frame_latency: Option<u32>Desired maximum number of frames that the presentation engine should queue in advance.
Use 1 for low-latency, and 2 for high-throughput.
See wgpu::SurfaceConfiguration::desired_maximum_frame_latency for details.
None => Let wgpu pick a default (currently 2).
Implementations
Sourceimpl SurfaceConfig
impl SurfaceConfig
Sourcepub const LOW_LATENCY: Self
pub const LOW_LATENCY: Self
Good default for GUIs with very little (or no) extra GPU work.
Sourcepub const HIGH_THROUGHPUT: Self
pub const HIGH_THROUGHPUT: Self
Good default for GUIs with a lot of extra GPU work, or that want to prioritize smoothness over latency.