pub type CallbackResources = TypeMap;Expand description
You can use this for storage when implementing CallbackTrait.
Aliased Type
struct CallbackResources { /* private fields */ }pub type CallbackResources = TypeMap;You can use this for storage when implementing CallbackTrait.
struct CallbackResources { /* private fields */ }