pub enum WgpuSetup {
CreateNew {
supported_backends: Backends,
power_preference: PowerPreference,
device_descriptor: Arc<dyn Fn(&Adapter) -> DeviceDescriptor<'static> + Send + Sync>,
},
Existing {
instance: Arc<Instance>,
adapter: Arc<Adapter>,
device: Arc<Device>,
queue: Arc<Queue>,
},
}Variants
CreateNew
Construct a wgpu setup using some predefined settings & heuristics. This is the default option. You can customize most behaviours overriding the supported backends, power preferences, and device description.
This can also be configured with the environment variables:
WGPU_BACKEND:vulkan,dx11,dx12,metal,opengl,webgpuWGPU_POWER_PREF:low,highornone
Fields

supported_backends: BackendsBackends that should be supported (wgpu will pick one of these).
For instance, if you only want to support WebGL (and not WebGPU),
you can set this to wgpu::Backends::GL.
By default on web, WebGPU will be used if available.
WebGL will only be used as a fallback,
and only if you have enabled the webgl feature of crate wgpu.

power_preference: PowerPreferencePower preference for the adapter.
Existing
Run on an existing wgpu setup.